pub struct EventGroup { /* private fields */ }Expand description
Manages a group of event listeners. When the group is disposed, all listeners are removed.
Implementations
sourceimpl EventGroup
impl EventGroup
pub fn new() -> Self
sourcepub fn add_listener(
&self,
dispatcher: IEventDispatcher,
type_: String,
listener: Listener
)
pub fn add_listener(
&self,
dispatcher: IEventDispatcher,
type_: String,
listener: Listener
)
Register a listener with this group.
sourcepub fn add_disposing_listener(
&self,
dispatcher: IEventDispatcher,
type_: String,
listener: Listener
)
pub fn add_disposing_listener(
&self,
dispatcher: IEventDispatcher,
type_: String,
listener: Listener
)
Register a listener with this group, all listeners are removed when it’s fired.