pub struct Signal0 {
pub inner: SignalBase,
}Expand description
A zero-argument signal. See Signal1 and Signal2 for different arities.
Fields
inner: SignalBaseImplementations
sourceimpl Signal0
impl Signal0
sourcepub fn new(listener: Option<Listener0>) -> Self
pub fn new(listener: Option<Listener0>) -> Self
@param listener An optional listener to immediately connect to the signal.
sourcepub fn connect(&self, listener: Listener0, prioritize: bool) -> SignalConnection
pub fn connect(&self, listener: Listener0, prioritize: bool) -> SignalConnection
Connects a listener to this signal. @param prioritize True if this listener should fire before others. @returns A SignalConnection, that can be disposed to remove the listener.