Enum dx::SystemError [−][src]
#[non_exhaustive]
pub enum SystemError {
CoglSystemErrorUnsupported,
CoglSystemErrorNoMemory,
// some variants omitted
}Error enumeration for Cogl
The SystemError::CoglSystemErrorUnsupported error can be thrown for a
variety of reasons. For example:
<itemizedlist>
<listitem>``<para>You’ve tried to use a feature that is not
advertised by has_feature. This could happen if you create
a 2d texture with a non-power-of-two size when
FeatureID::OglFeatureIdTextureNpot is not advertised.</para>``</listitem>
<listitem>``<para>The GPU can not handle the configuration you have
requested. An example might be if you try to use too many texture
layers in a single Pipeline``</para>``</listitem>
<listitem>``<para>The driver does not support some
configuration.</para>``</listiem>
</itemizedlist>
Currently this is only used by Cogl API marked as experimental so this enum should also be considered experimental.
Variants (Non-exhaustive)
You tried to use a feature or configuration not currently available.
You tried to allocate a resource such as a texture and there wasn’t enough memory.