Struct dx::foundation::ApplicationSettings
source · [−]pub struct ApplicationSettings {
pub title: String,
pub width: u32,
pub height: u32,
pub fullscreen: bool,
pub before: Box<dyn FnOnce(u32, u32)>,
pub preloader: Box<dyn FnOnce() -> Box<dyn Renderable>>,
}Expand description
Application settings
Fields
title: StringThe initial title of the application window.
width: u32Width of the viewport.
height: u32Height of the viewport.
fullscreen: boolShall the viewport be in fullscreen mode?
before: Box<dyn FnOnce(u32, u32)>Called before initializing the application host, usually to clear the window.
preloader: Box<dyn FnOnce() -> Box<dyn Renderable>>Called during application host initialization, usually to display progress.