Struct dx::foundation::Point3D
source · [−]#[repr(C)]pub struct Point3D<T> {
pub x: T,
pub y: T,
pub z: T,
}Expand description
A 3d Vector tagged with a unit.
Fields
x: TThe x (traditionally, horizontal) coordinate.
y: TThe y (traditionally, vertical) coordinate.
z: TThe z (traditionally, depth) coordinate.
Implementations
sourceimpl<T> Vector3D<T>
impl<T> Vector3D<T>
sourcepub const fn new(x: T, y: T, z: T) -> Vector3D<T>
pub const fn new(x: T, y: T, z: T) -> Vector3D<T>
Constructor, setting all components to zero. Constructor taking scalar values directly.
sourcepub fn splat(v: T) -> Vector3D<T> where
T: Clone,
pub fn splat(v: T) -> Vector3D<T> where
T: Clone,
Constructor setting all components to the same value.
sourcepub fn from_untyped(p: Vector3D<T>) -> Vector3D<T>
pub fn from_untyped(p: Vector3D<T>) -> Vector3D<T>
Tag a unitless value with units.
sourcepub fn abs(self) -> Vector3D<T> where
T: Signed,
pub fn abs(self) -> Vector3D<T> where
T: Signed,
Computes the vector with absolute values of each component.
Example
assert_eq!(Vector3D::new(-1, 0, 2).abs(), Vector3D::new(1, 0, 2));
let vec = Vector3D::new(f32::NAN, 0.0, -f32::MAX).abs();
assert!(vec.x.is_nan());
assert_eq!(vec.y, 0.0);
assert_eq!(vec.z, f32::MAX);Panics
The behavior for each component follows the scalar type’s implementation of
num_traits::Signed::abs.
sourceimpl<T> Vector3D<T> where
T: Copy,
impl<T> Vector3D<T> where
T: Copy,
sourcepub fn cross(self, other: Vector3D<T>) -> Vector3D<T> where
T: Sub<T, Output = T> + Mul<T, Output = T>,
pub fn cross(self, other: Vector3D<T>) -> Vector3D<T> where
T: Sub<T, Output = T> + Mul<T, Output = T>,
Cross product.
sourcepub fn component_mul(self, other: Vector3D<T>) -> Vector3D<T> where
T: Mul<T, Output = T>,
pub fn component_mul(self, other: Vector3D<T>) -> Vector3D<T> where
T: Mul<T, Output = T>,
Returns the component-wise multiplication of the two vectors.
sourcepub fn component_div(self, other: Vector3D<T>) -> Vector3D<T> where
T: Div<T, Output = T>,
pub fn component_div(self, other: Vector3D<T>) -> Vector3D<T> where
T: Div<T, Output = T>,
Returns the component-wise division of the two vectors.
sourcepub fn to_untyped(self) -> Vector3D<T>
pub fn to_untyped(self) -> Vector3D<T>
Drop the units, preserving only the numeric value.
sourceimpl<T> Vector3D<T> where
T: Mul<T, Output = T> + Add<T, Output = T> + Copy,
impl<T> Vector3D<T> where
T: Mul<T, Output = T> + Add<T, Output = T> + Copy,
sourcepub fn square_length(self) -> T
pub fn square_length(self) -> T
Returns the vector’s length squared.
sourceimpl<T> Vector3D<T> where
T: Float,
impl<T> Vector3D<T> where
T: Float,
sourcepub fn try_normalize(self) -> Option<Vector3D<T>>
pub fn try_normalize(self) -> Option<Vector3D<T>>
Returns the vector with length of one unit.
Unlike Vector2D::normalize, this returns None in the case that the
length of the vector is zero.
sourcepub fn robust_normalize(self) -> Vector3D<T>
pub fn robust_normalize(self) -> Vector3D<T>
Return the normalized vector even if the length is larger than the max value of Float.
sourcepub fn with_max_length(self, max_length: T) -> Vector3D<T>
pub fn with_max_length(self, max_length: T) -> Vector3D<T>
Return this vector capped to a maximum length.
sourcepub fn with_min_length(self, min_length: T) -> Vector3D<T>
pub fn with_min_length(self, min_length: T) -> Vector3D<T>
Return this vector with a minimum length applied.
sourcepub fn clamp_length(self, min: T, max: T) -> Vector3D<T>
pub fn clamp_length(self, min: T, max: T) -> Vector3D<T>
Return this vector with minimum and maximum lengths applied.
sourceimpl<T> Vector3D<T> where
T: NumCast + Copy,
impl<T> Vector3D<T> where
T: NumCast + Copy,
sourcepub fn cast<NewT>(self) -> Vector3D<NewT> where
NewT: NumCast,
pub fn cast<NewT>(self) -> Vector3D<NewT> where
NewT: NumCast,
Cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
sourcepub fn try_cast<NewT>(self) -> Option<Vector3D<NewT>> where
NewT: NumCast,
pub fn try_cast<NewT>(self) -> Option<Vector3D<NewT>> where
NewT: NumCast,
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
sourcepub fn to_usize(self) -> Vector3D<usize>
pub fn to_usize(self) -> Vector3D<usize>
Cast into an usize vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
sourcepub fn to_u32(self) -> Vector3D<u32>
pub fn to_u32(self) -> Vector3D<u32>
Cast into an u32 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.