Struct dx::support::glyph::SectionText
[−]Expand description
Text to layout together using a font & scale.
Fields
text: &'a strText to render
scale: PxScalePosition on screen to render text, in pixels from top-left. Defaults to (0, 0).
font_id: FontIdFont id to use for this section.
It must be a valid id in the FontMap used for layout calls.
The default FontId(0) should always be valid.