pub struct Command<T> { /* private fields */ }Expand description
A collection of async operations.
You should be able to turn a future easily into a Command, either by
using the From trait or Command::perform.
Implementations
impl<T> Command<T>
impl<T> Command<T>
pub fn perform<A>(
future: impl Future<Output = T> + Send + 'static,
f: impl Fn(T) -> A + Send + 'static
) -> Command<A>
pub fn perform<A>(
future: impl Future<Output = T> + Send + 'static,
f: impl Fn(T) -> A + Send + 'static
) -> Command<A>
Creates a Command that performs the action of the given future.
pub fn map<A>(self, f: impl Fn(T) -> A + Send + Sync + 'static) -> Command<A> where
T: 'static,
pub fn map<A>(self, f: impl Fn(T) -> A + Send + Sync + 'static) -> Command<A> where
T: 'static,
Applies a transformation to the result of a Command.
pub fn batch(commands: impl IntoIterator<Item = Command<T>>) -> Command<T>
pub fn batch(commands: impl IntoIterator<Item = Command<T>>) -> Command<T>
Creates a Command that performs the actions of all the given
commands.
Once this command is run, all the commands will be executed at once.